.TH "flt" 2 " June 6th 1997" "Fractales Group" "Scilab Function"

.SH NAME
flt -  Fast Legendre transform
.SH Usage
.nf
[u,s] = flt(x,y[,ccv])
.fi 
.SH Input parameters
.TP
o 
\fBx\fP : real valued vector [1,N] 
samples support of the function y

.TP
o 
\fBy\fP :  real valued vector [1,N] 
samples of function y = y(x)

.TP
o 
\fBccv\fP : optional argument to choose between convex (\fIccv\fP
= 0) and concave (\fIccv\fP = 1) envelope.  Default value is \fIccv\fP =
1 (concave)
.RE

.SH Output parameters


.RS

.TP
o 
\fBu\fP : real valued vector [1,M]  Legendre
transform of input \fIy\fP. Note that, since \fIu\fP stems from the
envelope of \fIy\fP, in general \fIM\fP <= \fIN\fP.

.TP
o 
\fBs\fP : real valued vector [1,M]  
Variable of the Legendre transform of \fIy\fP.

.SH DESCRIPTION
Computes the Legendre transform of \fIy\fP  y\(ha*\fP(s) = sup_{\fPx in X}\fP[s.x - y(x)]
.SH Example:
.nf
//Function synthesis
m0 = .55 ; m1 = 1 - m0 ;
m2 = .95 ; m3 = 1 - m2 ;
q = linspace(-20,20,201) ;
tau1 = - log2(exp(q.*log(m0)) + exp(q.*log(m1))) ;
tau2 = - log2(exp(q.*log(m2)) + exp(q.*log(m3))) ;
tau3 = min(tau1 , tau2) ;

//Legendre Transforms
[u1,s1] = flt(q,tau1) ;
[u2,s2] = flt(q,tau2) ;
[u3,s3] = flt(q,tau3) ;

// Vizualisation 
plot2d(s3,u3,17) ; 
plot2d(s1,u1,18,'001') ; 
plot2d(s2,u2,19,'001') ;
.fi 
.SH AUTHOR
Paulo Goncalves
