.TH "idmt" 2 " June 6th 1997" "Fractales Group" "Scilab Function"

.SH NAME
idmt -  Inverse Discrete Mellin transform
.sp
Author: Paulo Goncalves
.sp
Computes the Inverse Fast Fourier-Mellin transform of a signal.
.sp
.sp
.SH Usage
.nf
[x,t] = idmt(mellin,beta,[M]) 
.fi
.SH Input parameters


.RS

.TP
o 
\fBmellin\fP :  complex vector [1,N]
Fourier-Mellin transform to be inverted. For a correct inversion of the Fourier-Mellin
transform, the direct Fourier-Mellin transform \fImellin\fP must have been computed from \fIfmin\fP
to \fB0.5 cycles per sec\fP.

.TP
o 
\fBbeta\fP : real vector [1,N]
Variable of the Mellin transform \fImellin\fP.

.TP
o 
\fBM\fP : positive integer. 
Number of time samples to be recovered from \fImellin\fP.
.RE

.SH Output parameters


.RS

.TP
o 
\fBx\fP : complex vector [1,M]
Inverse Fourier-Mellin transform of \fImellin\fP.

.TP
o 
\fBt\fP : time variable of the Inverse Fourier-Mellin transform \fIx\fP.
.RE

.SH Description
The Inverse Fourier-Mellin transform can be viewed as an Inverse Fast
Fourier Transform which result is assumed geometrically sampled. To
recover the initial time signal, a Discrete Inverse Fourier Transform
is applied to this geometrically Fourier representation.
\fBImportant\fP The Inverse Fourier-Mellin transform is correct only if
the direct Fourier-Mellin transform has been computed from \fIfmin\fP
to \fB0.5 cycles per sec.\fP
.SH See also:
dmt, dilate
.SH Example:
.nf
//Signal synthesis
x = morlet(0.1,32) ; 
plot(x)
//Computation of the Mellin transform
[mellin,beta] = dmt(x,0.01,0.5,128) ;
plot(beta,abs(mellin))
//Computation of the Inverse Mellin transform

[y,t] = idmt(mellin,beta,65) ;
plot(t,abs(x-y))
.fi 
